Skip to contents

This function gives the name of the person, or persons, who contributed the sequence and their emails, if they are present and selected.

Usage

OEIS_author(x, email = FALSE)

Arguments

x

Can be one of the following:

  • A character string with sequence ID.

  • A OEIS_internal S3 class object, with sequence internal format.

  • A S3 classes object OEIS_xml and xml_document, with sequence content from OEIS web.

  • An object of OEIS_sequence class, that contains all sequence related data.

email

A logical, by specifying: email = TRUE, the author's email is returned, if present, with the author's name. The default value of email is FALSE.

Value

A character vector with the OEIS sequence authors and emails.

Examples

if (FALSE) { # \dontrun{
id <- "A169890"
OEIS_author(id, email = TRUE)
} # }