Skip to contents

The comments field in OEIS sequence entries is for information that does not quite fit in other fields.

Usage

OEIS_comments(x)

Arguments

x

Can be one of the following:

  • A character string with sequence ID.

  • A OEIS_internal S3 class object, with sequence internal format.

  • A S3 classes object OEIS_xml and xml_document, with sequence content from OEIS web.

  • An object of OEIS_sequence class, that contains all sequence related data.

Value

A character string with the OEIS sequence comments lines from the sequence or NULL if there are no comments.

Examples

if (FALSE) { # \dontrun{
id <- "A105805"
internal_format <- OEIS_internal_format(id)
example <- OEIS_comments(internal_format)
cat(example, sep = "\n")
} # }