This lines are useful to get all the sequence format data.
Examples
if (FALSE) { # \dontrun{
id <- "A008406"
xml <- OEIS_xml(id)
df <- OEIS_df(xml)
df
} # }
This lines are useful to get all the sequence format data.
if (FALSE) { # \dontrun{
id <- "A008406"
xml <- OEIS_xml(id)
df <- OEIS_df(xml)
df
} # }