Skip to contents

This function can be used to download a bfile from https://oeis.org/.

Usage

OEIS_download_bfile(ID, destpath, ...)

Arguments

ID

A string with the OEIS sequence identifier ID number. The A-number or sequence ID is the absolute catalog number of the sequence. It consists of "A" followed by 6 digits.

destpath

A character string with the name where the downloaded bfile is saved

...

Additional parameters (see download.file)

Value

An (invisible) integer code, 0 for success and non-zero for failure.

Examples

if (FALSE) { # \dontrun{
OEIS_download_bfile("A102030", "tests", quiet = TRUE)
} # }