Skip to contents

In OEIS internal format, each sequence, is described by about 10 lines, each line beginning %x Aabcdef where x is a letter (I, S, T, N, etc.) and abcdef is the 6-digit identification number (or catalog number) of the sequence. Each sequence gets a unique A-number.

Usage

OEIS_internal_format(ID)

Arguments

ID

A string with the OEIS sequence identifier ID number. The A-number or sequence ID is the absolute catalog number of the sequence. It consists of "A" followed by 6 digits.

Value

An object of the classes data.frame and OEIS_internal with the full sequence text internal format. OEIS_check()

Examples

if (FALSE) { # \dontrun{
id <- "A000055"
OEIS_internal_format(id)
} # }