Skip to contents

Retrieve the total number of sequences in the OEIS database

Usage

OEIS_total_sequences()

Value

An integer with the total number of sequences, or NA_integer_ if the extraction fails or there is no internet connection.

See also

Examples

if (FALSE) { # \dontrun{
OEIS_total_sequences()
} # }