Skip to contents

The XML document contains all the information from the OEIS web related to the sequence.

Usage

OEIS_xml(ID)

Arguments

ID

A string with the OEIS sequence identifier ID number. The A-number or sequence ID is the absolute catalog number of the sequence. It consists of "A" followed by 6 digits.

Value

An OEIS_xml S3 class and xml_document from OEIS web with the sequence content.

Examples

if (FALSE) { # \dontrun{
 id <- "A000156"
 test_seq_xml <- OEIS_xml(id)
 class(test_seq_xml)
} # }