This function gives the name of the person, or persons, who contributed the sequence and their emails, if they are present and selected.
Arguments
- x
can be one of the following:
A character string with sequence
ID.A
OEIS_internalS3 class object, with sequence internal format.A S3 classes object
OEIS_xmlandxml_document, with sequence content from OEIS web.An object of
OEIS_sequenceclass, that contains all sequence related data.An object of
OEIS_bfileclass.