OEIS sequence authors from internal format, or from the sequence ID.
Source: R/OEIS_author.R
OEIS_author.RdThis function gives the name of the person, or persons, who contributed the sequence and their emails, if they are present and selected.
Arguments
- x
Can be one of the following:
A character string with sequence
ID.A
OEIS_internalS3 class object, with sequence internal format.A S3 classes object
OEIS_xmlandxml_document, with sequence content from OEIS web.An object of
OEIS_sequenceclass, that contains all sequence related data.
A logical, by specifying:
email = TRUE, the author's email is returned, if present, with the author's name. The default value ofemailisFALSE.