A bfile is a text formatted file that provides many more terms of a
sequence than the typical fifty to eighty terms that can be shown in the main
sequence entry.
Value
A S3 object of the class OEIS_bfile with the following structure:
bfile_name: Name of
bfile.bfile_url: Url to
bfilein the OEIS server.min_n: Minimum
nposition of the first term for available values of the sequence.max_n: Maximum
nposition of the last term for available values of the sequence.comments: Text comments included into the
bfiledata: A data frame including all data within the
bfilewith two columns: n and other named as the sequenceIDincluding sequence values for a(n).