This function can be used to download a bfile from https://oeis.org/.
Arguments
- ID
A string with the OEIS sequence identifier
IDnumber. The A-number or sequenceIDis the absolute catalog number of the sequence. It consists of "A" followed by 6 digits.- destpath
A character string with the name where the downloaded
bfileis saved- ...
Additional parameters (see download.file)