This is the data included in the sequence. These lines give the beginning of the sequence. Ideally the entry gives enough terms to fill about three lines on the screen. The terms must be integers. If the terms are fractions, then the numerators and denominators appear as separate sequences, labeled with the Keyword "frac", and with links connecting the two sequences. Only sequences that are well-defined and of general interest are included
Note
For more terms see OEIS_bfile().
Examples
if (FALSE) { # \dontrun{
# Wieferich primes: primes p such that p^2 divides 2^(p-1) - 1.
id <- "A001220"
internal_format <- OEIS_internal_format(id)
OEIS_terms(internal_format)
} # }