Retrieve the total number of sequences in the OEIS database
Source:R/OEIS_total_sequences.R
OEIS_total_sequences.RdRetrieve the total number of sequences in the OEIS database
Value
An integer with the total number of sequences, or NA_integer_
if the extraction fails or there is no internet connection.