The XML document contains all the information from the OEIS web related to
the sequence.
Examples
if (FALSE) { # \dontrun{
id <- "A000156"
test_seq_xml <- OEIS_xml(id)
class(test_seq_xml)
} # }
The XML document contains all the information from the OEIS web related to
the sequence.
if (FALSE) { # \dontrun{
id <- "A000156"
test_seq_xml <- OEIS_xml(id)
class(test_seq_xml)
} # }